@@ -127,8 +127,9 @@ else:
     KOLLA_BRANCH_NAME = 'stable/{}'.format(KOLLA_OPENSTACK_RELEASE)
 
 GLOBAL_VARIABLE_MAP = {
-    "|KOLLA_OPENSTACK_RELEASE|": KOLLA_OPENSTACK_RELEASE,
-    "|KOLLA_BRANCH_NAME|": KOLLA_BRANCH_NAME,
+    '|KOLLA_OPENSTACK_RELEASE|': KOLLA_OPENSTACK_RELEASE,
+    '|KOLLA_BRANCH_NAME|': KOLLA_BRANCH_NAME,
+    '|KOLLA_BRANCH_NAME_DASHED|': KOLLA_BRANCH_NAME.replace('/', '-'),
 }
 
 def replace_global_vars(app, docname, source):
